@@ -2,10 +2,18 @@
 
 /* LDAP Global Preferences. Change these to your setup. */
 
-$ldap_host = 'ldap.example.net';
+/* $ldap_host can be a space-separated list of hosts, for automatic failover */
+$ldap_host = '10.10.10.1 10.10.10.2';
+
+/* $ldap_master_host MUST be the single, master LDAP server for writes. */
+$ldap_master_host = '10.10.10.1';
+
 $ldap_username = 'cn';
 $ldap_base_dn = 'o=organization,c=country';
 
+/* LDAP network timeout in seconds */
+$ldap_network_timeout = 10;
+
 /* Credentials for the Squirrel Virtual user. If you don't have such a user, go
  * ahead and create him. */
 $ldap_bind_dn = "uid=squirrel,ou=Squirrel,ou=Services,o=organization,c=country";
@@ -28,7 +36,7 @@ $prefs_default = array (
 'sent_folder' => 'INBOX.Sent' ,
 'draft_folder' => 'INBOX.Drafts' ,
 'show_html_default' =>  0,
-'chosen_theme' => '../themes/bluesteel_theme.php',
+'chosen_theme' => '../themes/plain_blue_theme.php',
 'javascript_setting' =>  2,
 'show_num' => 20,
 'alt_index_colors' => 0,
@@ -37,13 +45,13 @@ $prefs_default = array (
 'wrap_at' => 86,
 'editor_size' => 76,
 'include_self_reply_all' => 0,
-'show_xmailer_default' => 0,
+'show_xmailer_default' => 1,
 'attachment_common_show_images' => 0,
 'pf_subtle_link' => 1,
 'pf_cleandisplay' => 0,
 'mdn_user_support' => 1,
 'compose_new_win' => 0,
-'language' => 'en_US',
+'language' => 'en_GR',
 'location_of_buttons' => 'between',
 'use_signature' => 0,
 'prefix_sig' => 1,
@@ -53,13 +61,15 @@ $prefs_default = array (
 'order4' => 5,
 'order5' => 4,
 'order6' => 6,
-'left_size' => 180,
+//'left_size' => 150,
+'left_size' => 200,
 'unseen_notify' => 3, /* 2 */
 'unseen_type' => 2, /* 1 */
 'collapse_folders' => 1, /* 0 */
 'date_format' => 6,
 'hour_format' => 1,
 'search_memory' => 0,
+'mailbox_select_style' => 0,
 /* These are for enabling the special status of INBOX.Trash,Sent,Draft folders */
 'move_to_trash' => 1,
 'move_to_sent' => 1,
@@ -67,7 +77,17 @@ $prefs_default = array (
 /* Server-side sorting breaks if we do not provide a default */
 'sort' => 0,
 /* Mailfetch cypher always on */
-'mailfetch_cypher' => 'on'
+'mailfetch_cypher' => 'on',
+/* Some more defaults for translate plugin */
+'translate_server' => 'babelfish',
+'translate_location' => 'center',
+'translate_show_read' => 1,
+'translate_show_send' => 0,
+'translate_same_window' => 0,
+/* Avelsizes */
+'folder_sizes_subtotals' => 0,
+'folder_sizes_left_link' => 1,
+'folder_sizes_on_folder_page' => 1
 );
 
 
