@@ -4,37 +4,53 @@
     *  By Alexandros Vellis <avel@noc.uoa.gr>
     *  Based on Retrieve User Data Plugin
     *  by Ralf Kraudelt <kraude@wiwi.uni-rostock.de>
-    *
     */
-
-require_once('../plugins/ldapuserdata/config.php');
+    
 
 function squirrelmail_plugin_init_ldapuserdata() {
 	global $squirrelmail_plugin_hooks;
+	global $ldap_bind_dn, $ldap_host, $ldap_master_host, $ldap_username, $ldap_base_dn;
+	global $ldap_network_timeout, $ldap_bind_dn, $ldap_bind_pw, $ldap_manager_dn, $ldap_manager_pw;
+	global $ldap_objectclass, $prefs_default, $ldap_attributes, $boolean_attrs, $multivalue_attrs;
+	global $alternateemail_attrs;
+
+	include(SM_PATH . 'plugins/ldapuserdata/config.php');
 
 	// $squirrelmail_plugin_hooks["login_verified"]["ldapuserdata"] = "check_userdata";
 	$squirrelmail_plugin_hooks["login_before"]["ldapuserdata"] = "get_userdata";
 	$squirrelmail_plugin_hooks["logout"]["ldapuserdata"] = "flush_userdata";
 }
 
-/* My convenience function for connecting to the lDAP database.
+/* My convenience function for connecting to the LDAP database.
  * $type is one of 'user', 'squirrel' or 'manager'.
+ * If must do writes, connect to master LDAP, so $master = true.
  */
 
-function connect_to_ldap ($type = 'user') {
-
-	global $ldap_host, $username, $ldap_base_dn;
+function connect_to_ldap ($type = 'user', $master = false) {
+	global $ldap_host, $ldap_master_host, $username, $ldap_base_dn, $ldap_network_timeout;
 	global $ldap_bind_dn, $ldap_bind_pw, $ldap_manager_dn, $ldap_manager_pw;
 	global $cleartext_passwd;
 
+	if($master) {
+		$ldap_host = $ldap_master_host;
+	}
 	$ldap_error = 0;
 
 	if (!($ldap = ldap_connect($ldap_host))) {
-		$ldap_error = 1;
 		print "Could not connect to LDAP!";
 		return false;
 	}
 
+	if (!ldap_set_option($ldap, LDAP_OPT_PROTOCOL_VERSION, 3)) { 
+		print "Failed to set protocol version to 3";
+	}
+
+	/* if (!$master) {
+		if (!ldap_set_option($ldap, LDAP_OPT_NETWORK_TIMEOUT, $ldap_network_timeout)) {
+			print "Failed to set network timeout.\n";
+		}
+	}*/
+	
 	switch ($type) {
 		case 'manager':
 			$bind_result = ldap_bind( $ldap, $ldap_manager_dn, $ldap_manager_pw);
@@ -60,36 +76,46 @@ function connect_to_ldap ($type = 'user') {
  */
    
 function get_userdata() {
-	/* Make these global, otherwise redirect.php won't get a hint about this. */
-	global $login_username, $imapServerAddress, $prefs_cache, $prefs_before;
+	global $login_username, $imapServerAddress;
 	global $full_name, $email_address;
+	global $ldap_bind_dn, $ldap_host;
 
-	/* fill $prefs_cache with data from LDAP. */
-	$prefs_cache = retrieve_data($login_username);
+	/* fill $ldap_prefs_cache with data from LDAP. */
+	$ldap_prefs_cache = retrieve_data($login_username);
+
+	/*
+	print "<pre>";
+	print_r($ldap_prefs_cache);
+	print_r($_SESSION);
+	print_r ($_POST);
+	print "</pre>";
+	*/
 
-	
 	/* $prefs_before will remain, for checking if there are any changes to
 	 * write in the end. */ 
-	$prefs_before = $prefs_cache;
+	$prefs_before = $ldap_prefs_cache;
+	$prefs_tralala = $ldap_prefs_cache;
 
-	$imapServerAddress = $prefs_cache['imapServerAddress'];
-	$full_name = $prefs_cache['full_name'];
-	$email_address = $prefs_cache['email_address'];
-	session_register('prefs_cache');
-	session_register('prefs_before');
-	session_register('imapServerAddress');
-	session_register('full_name');
-	session_register('email_address');
+	$imapServerAddress = $ldap_prefs_cache['imapServerAddress'];
+	$full_name = $ldap_prefs_cache['full_name'];
+	$email_address = $ldap_prefs_cache['email_address'];
+	$prefs_are_cached = true;
+
+	sqsession_register($prefs_are_cached, 'prefs_are_cached');
+	sqsession_register($ldap_prefs_cache, 'ldap_prefs_cache');
+	sqsession_register($prefs_before, 'prefs_before');
+	sqsession_register($imapServerAddress, 'imapServerAddress');
+	sqsession_register($full_name, 'full_name');
+	sqsession_register($email_address, 'email_address');
 }
 
 
 function retrieve_data ($uid) {
-
 	global $ldap_host, $username, $ldap_base_dn, $ldap_bind_dn, $ldap_bind_pw;
 	global $ldap_manager_dn, $ldap_manager_pw;
 	global $ldap_objectclass, $prefs_default, $ldap_attributes, $boolean_attrs, $multivalue_attrs;
       
-	$ldap = connect_to_ldap('squirrel');
+	$ldap = connect_to_ldap('squirrel', false);
 
 	// $ldapattrarray = array_values($ldap_attributes);
 	// print "<pre>"; print_r(array_keys($ldap_attributes)); print "</pre>";
@@ -204,14 +230,14 @@ function retrieve_data ($uid) {
 		
 		// print "I will modify objectclass as follows:";
 		// print "<pre>"; print_r($newinfo); print "</pre>";
-		$ldap2 = connect_to_ldap('manager');
+		$ldap2 = connect_to_ldap('manager', true);
 		
 		if(!ldap_modify($ldap2, "uid=$uid,ou=people,$ldap_base_dn" , $newinfo)) {
 			print "<STRONG>Error while updating your objectclass! Could not modify LDAP data.</strong>";
 			exit;
 		} 
 		ldap_close($ldap2);
-		// $HTTP_SESSION_VARS['first_time_user'] = 1;
+		// $_SESSION['first_time_user'] = 1;
 		//session_register($first_time_user);
 	} 
 	while(list($ldapattr, $squirrelattr) = each($boolean_attrs)) {
@@ -223,39 +249,42 @@ function retrieve_data ($uid) {
 			}
 		}
 	}
-
 	return($prefs);
 
 }
 
-   /*
-    *  write user data to LDAP database
-    */
+/*
+ *  write user data to LDAP database
+ */
    
 function flush_userdata() {
-      include("../plugins/ldapuserdata/config.php");
+      include(SM_PATH . "plugins/ldapuserdata/config.php");
 
-      global $username, $HTTP_SESSION_VARS;
+      global $username;
       global $ldap_host;
       global $ldap_objectclass, $prefs_default, $ldap_attributes, $boolean_attrs;
 
-      global $prefs_cache;
+	if(is_array($_SESSION['ldap_prefs_cache'])) {
+		$ldap_prefs_cache = $_SESSION['ldap_prefs_cache'];
+	}
 
-      // prepare data
-      $attr_to_write=array();
-      
-      while(list($ldapattr, $squirrelattr) = each($ldap_attributes)) {
-          if( !( ($ldapattr == "cn") || ($ldapattr == "mail") || ($ldapattr == "mailhost")) ) {
-	  	
-	      if($HTTP_SESSION_VARS['prefs_cache'][$squirrelattr] != $HTTP_SESSION_VARS['prefs_before'][$squirrelattr] )
-	      		if ($HTTP_SESSION_VARS['prefs_cache'][$squirrelattr] != "" ) {
-	          // print "<br>DEBUG: Checking if ".$HTTP_SESSION_VARS['prefs_cache'][$squirrelattr]." is different than ".$HTTP_SESSION_VARS['prefs_before'][$squirrelattr]."<br>";
-		          $attr_to_write[$ldapattr] = $HTTP_SESSION_VARS['prefs_cache'][$squirrelattr];
+	// prepare data
+	$attr_to_write=array();
+
+	while(list($ldapattr, $squirrelattr) = each($ldap_attributes)) {
+		if( !( ($ldapattr == "cn") || ($ldapattr == "mail") || ($ldapattr == "mailhost")) ) {
+	
+		// print "<br>DEBUG: $squirrelattr - Checking if ".$ldap_prefs_cache[$squirrelattr]."
+		// is different than ".$_SESSION['prefs_before'][$squirrelattr]."<br>";
+
+		if($_SESSION['ldap_prefs_cache'][$squirrelattr] != $_SESSION['prefs_before'][$squirrelattr] )
+			if ($_SESSION['ldap_prefs_cache'][$squirrelattr] != "" ) {
+				$attr_to_write[$ldapattr] = $_SESSION['ldap_prefs_cache'][$squirrelattr];
 			} else {
-			  $attr_to_del[$ldapattr] = $HTTP_SESSION_VARS['prefs_before'][$squirrelattr];
-	      }
-	  }
-      }
+				$attr_to_del[$ldapattr] = $_SESSION['prefs_before'][$squirrelattr];
+			}
+		}
+	}
 
 	/* Handle boolean attributes */
 	while(list($ldapattr, $squirrelattr) = each($boolean_attrs)) {
@@ -269,22 +298,22 @@ function flush_userdata() {
 	}
 
 	/* Handle multivalue attributes */
-	if($_SESSION['prefs_cache']['mailfetch_server_number'] > 0) {
+	if($_SESSION['ldap_prefs_cache']['mailfetch_server_number'] > 0) {
 		//print "putting mailfetch vars";
 		
-		for ($i=0; $i < $_SESSION['prefs_cache']['mailfetch_server_number']; $i++) {
+		for ($i=0; $i < $_SESSION['ldap_prefs_cache']['mailfetch_server_number']; $i++) {
 			//print "writing # $i";
 
-			$newarray[0] = $_SESSION['prefs_cache']['mailfetch_server_'.$i];
-			$newarray[1] = $_SESSION['prefs_cache']['mailfetch_alias_'.$i]; 
-			$newarray[2] = $_SESSION['prefs_cache']['mailfetch_user_'.$i]; 
-			$newarray[3] = $_SESSION['prefs_cache']['mailfetch_pass_'.$i];
-			$newarray[4] = $_SESSION['prefs_cache']['mailfetch_cypher_'.$i];
-			$newarray[5] = $_SESSION['prefs_cache']['mailfetch_lmos_'.$i]; 
-			$newarray[6] = $_SESSION['prefs_cache']['mailfetch_login_'.$i];
-			$newarray[7] = $_SESSION['prefs_cache']['mailfetch_fref_'.$i]; 
-			$newarray[8] = $_SESSION['prefs_cache']['mailfetch_subfolder_'.$i];
-			$newarray[9] = $_SESSION['prefs_cache']['mailfetch_uidl_'.$i]; 
+			$newarray[0] = $_SESSION['ldap_prefs_cache']['mailfetch_server_'.$i];
+			$newarray[1] = $_SESSION['ldap_prefs_cache']['mailfetch_alias_'.$i]; 
+			$newarray[2] = $_SESSION['ldap_prefs_cache']['mailfetch_user_'.$i]; 
+			$newarray[3] = $_SESSION['ldap_prefs_cache']['mailfetch_pass_'.$i];
+			$newarray[4] = $_SESSION['ldap_prefs_cache']['mailfetch_cypher_'.$i];
+			$newarray[5] = $_SESSION['ldap_prefs_cache']['mailfetch_lmos_'.$i]; 
+			$newarray[6] = $_SESSION['ldap_prefs_cache']['mailfetch_login_'.$i];
+			$newarray[7] = $_SESSION['ldap_prefs_cache']['mailfetch_fref_'.$i]; 
+			$newarray[8] = $_SESSION['ldap_prefs_cache']['mailfetch_subfolder_'.$i];
+			$newarray[9] = $_SESSION['ldap_prefs_cache']['mailfetch_uidl_'.$i]; 
 			
 			$mailfetchpref[$i] = implode (":", $newarray);
 			//print_r($mailfetchpref);
@@ -321,8 +350,7 @@ function flush_userdata() {
 	 */
 	
 	if(!(sizeof($attr_to_write) == 0)) {
-		$ldap = connect_to_ldap('manager');
-
+		$ldap = connect_to_ldap('manager', true);
 
 	//	$objarr = array("objectClass");
 		/* Check if we have objectClass $ldap_objectclass (default: SquirrelMailUser) */
@@ -348,7 +376,7 @@ function flush_userdata() {
 
 	if(!(sizeof($attr_to_del) == 0)) {
 		if(sizeof($attr_to_write) == 0) {
-			$ldap = connect_to_ldap('manager');
+			$ldap = connect_to_ldap('manager', true);
 		}
 		
 		if(!ldap_mod_del($ldap, "uid=$username,ou=people,$ldap_base_dn", $attr_to_del)) {
@@ -360,6 +388,9 @@ function flush_userdata() {
 	}
 }
 
-/* $cleartext_password = OneTimePadDecrypt($password, $onetimepad); */
+function ldapuserdata_get_server($username) {
+
+	return $_SESSION['prefs_before']['imapServerAddress'];
+}
 
 ?>
